@@ -5,7 +5,7 @@ package Config::XrmDatabase;
 use v5.26;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Feature::Compat::Try;
 
@@ -405,7 +405,7 @@ sub to_string ( $self ) {
         push @records, "$key : $value";
     }
 
-   return join( "\n", @records );
+   return @records ? join( "\n", @records, '' ) : '';
 }
 
 
@@ -745,7 +745,7 @@ Config::XrmDatabase - Pure Perl X Resource Manager Database
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
